Tooltip Visual Test: Animations

    {}

    {
    	"show": {
    		"effect": "slideDown"
    	},
    	"hide": {
    		"effect": "slideUp"
    	}
    }

    {
    	"show": {
    		"effect": "explode"
    	},
    	"hide": {
    		"effect": "explode"
    	}
    }

    {
    	"show": {
    		"effect": "bounce"
    	},
    	"hide": {
    		"effect": "blind"
    	}
    }

    {
    	"show": {
    		"effect": "drop",
    		"direction": "right"
    	},
    	"hide": {
    		"effect": "drop",
    		"direction": "right"
    	}
    }